import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:okane/screen.dart';
import 'package:okane/ui/pages/budgets/add_budget.dart';
import 'package:okane/ui/state/core.dart';
import 'package:okane/ui/utils.dart';

class BudgetListPage extends StatelessWidget {
  const BudgetListPage({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<CoreCubit, CoreState>(
      builder: (context, state) {
        if (state.budgets.isEmpty) {
          return Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Text("No budgets"),
              OutlinedButton(
                onPressed: () {
                  showDialogOrModal(
                    context: context,
                    builder:
                        (_) => AddBudgetPopup(
                          onDone: () {
                            Navigator.of(context).pop();
                          },
                        ),
                  );
                },
                child: Text("Add"),
              ),
            ],
          );
        }

        return ListView.builder(
          itemCount: state.budgets.length,
          itemBuilder:
              (context, index) => ListTile(
                title: Text(state.budgets[index].name),
                selected: state.budgets[index] == state.activeBudget,
                trailing: IconButton(
                  icon: Icon(
                      Icons.delete,
                    color: Colors.redAccent,
                  ),
                  onPressed: () {
                    // TODO
                  },
                ),
                onTap: () {
                  GetIt.I.get<CoreCubit>().setActiveBudget(
                    state.budgets[index],
                  );
                  if (getScreenSize(context) == ScreenSize.small) {
                    Navigator.of(context).pushNamed("/budgets/details");
                  }
                },
              ),
        );
      },
    );
  }
}
